diff --git a/libraries/ui/src/main/java/androidx/media3/ui/PlayerView.java b/libraries/ui/src/main/java/androidx/media3/ui/PlayerView.java
index 158ff83b85..ed6f7412f4 100644
--- a/libraries/ui/src/main/java/androidx/media3/ui/PlayerView.java
+++ b/libraries/ui/src/main/java/androidx/media3/ui/PlayerView.java
@@ -424,7 +424,7 @@ public class PlayerView extends FrameLayout implements AdViewProvider {
if (customController != null) {
this.controller = customController;
} else if (controllerPlaceholder != null) {
- // Propagate attrs as playbackAttrs so that StyledPlayerControlView's custom attributes are
+ // Propagate attrs as playbackAttrs so that PlayerControlView's custom attributes are
// transferred, but standard attributes (e.g. background) are not.
this.controller = new PlayerControlView(context, null, 0, attrs);
controller.setId(R.id.exo_controller);
@@ -1522,7 +1522,7 @@ public class PlayerView extends FrameLayout implements AdViewProvider {
toggleControllerVisibility();
}
- // StyledPlayerControlView.VisibilityListener implementation
+ // PlayerControlView.VisibilityListener implementation
@Override
public void onVisibilityChange(int visibility) {
diff --git a/libraries/ui/src/main/res/values/attrs.xml b/libraries/ui/src/main/res/values/attrs.xml
index 172b9acf0e..d944b28bf1 100644
--- a/libraries/ui/src/main/res/values/attrs.xml
+++ b/libraries/ui/src/main/res/values/attrs.xml
@@ -162,7 +162,7 @@
-
+
diff --git a/libraries/ui/src/main/java/androidx/media3/ui/PlayerControlView.java b/libraries/ui/src/main/java/androidx/media3/ui/PlayerControlView.java
index a3e869f4ce..ce3ba265d2 100644
--- a/libraries/ui/src/main/java/androidx/media3/ui/PlayerControlView.java
+++ b/libraries/ui/src/main/java/androidx/media3/ui/PlayerControlView.java
@@ -89,12 +89,12 @@ import java.util.concurrent.CopyOnWriteArrayList;
/**
* A view for controlling {@link Player} instances.
*
- *
A StyledPlayerControlView can be customized by setting attributes (or calling corresponding
+ *
A PlayerControlView can be customized by setting attributes (or calling corresponding
* methods), or overriding drawables.
*
*
Attributes
*
* The following attributes can be set on a StyledPlayerControlView when used in a layout XML file:
*
*
* - {@code show_timeout} - The time between the last user interaction and the controls
@@ -160,13 +160,13 @@ import java.util.concurrent.CopyOnWriteArrayList;
*
- Default: {@code R.layout.exo_player_control_view}
*
* All attributes that can be set on {@link DefaultTimeBar} can also be set on a
* StyledPlayerControlView, and will be propagated to the inflated {@link DefaultTimeBar}
* unless the layout is overridden to specify a custom {@code exo_progress} (see below).
*
*
* Overriding drawables
*
* The drawables used by StyledPlayerControlView (with its default layout file) can be overridden by
* drawables with the same names defined in your application. The drawables that can be overridden
* are:
*
@@ -375,40 +375,32 @@ public class PlayerControlView extends FrameLayout {
context
.getTheme()
.obtainStyledAttributes(
- playbackAttrs,
- R.styleable.StyledPlayerControlView,
- defStyleAttr,
- /* defStyleRes= */ 0);
+ playbackAttrs, R.styleable.PlayerControlView, defStyleAttr, /* defStyleRes= */ 0);
try {
controllerLayoutId =
- a.getResourceId(
- R.styleable.StyledPlayerControlView_controller_layout_id, controllerLayoutId);
- showTimeoutMs = a.getInt(R.styleable.StyledPlayerControlView_show_timeout, showTimeoutMs);
+ a.getResourceId(R.styleable.PlayerControlView_controller_layout_id, controllerLayoutId);
+ showTimeoutMs = a.getInt(R.styleable.PlayerControlView_show_timeout, showTimeoutMs);
repeatToggleModes = getRepeatToggleModes(a, repeatToggleModes);
showRewindButton =
- a.getBoolean(R.styleable.StyledPlayerControlView_show_rewind_button, showRewindButton);
+ a.getBoolean(R.styleable.PlayerControlView_show_rewind_button, showRewindButton);
showFastForwardButton =
a.getBoolean(
- R.styleable.StyledPlayerControlView_show_fastforward_button, showFastForwardButton);
+ R.styleable.PlayerControlView_show_fastforward_button, showFastForwardButton);
showPreviousButton =
- a.getBoolean(
- R.styleable.StyledPlayerControlView_show_previous_button, showPreviousButton);
+ a.getBoolean(R.styleable.PlayerControlView_show_previous_button, showPreviousButton);
showNextButton =
- a.getBoolean(R.styleable.StyledPlayerControlView_show_next_button, showNextButton);
+ a.getBoolean(R.styleable.PlayerControlView_show_next_button, showNextButton);
showShuffleButton =
- a.getBoolean(
- R.styleable.StyledPlayerControlView_show_shuffle_button, showShuffleButton);
+ a.getBoolean(R.styleable.PlayerControlView_show_shuffle_button, showShuffleButton);
showSubtitleButton =
- a.getBoolean(
- R.styleable.StyledPlayerControlView_show_subtitle_button, showSubtitleButton);
- showVrButton =
- a.getBoolean(R.styleable.StyledPlayerControlView_show_vr_button, showVrButton);
+ a.getBoolean(R.styleable.PlayerControlView_show_subtitle_button, showSubtitleButton);
+ showVrButton = a.getBoolean(R.styleable.PlayerControlView_show_vr_button, showVrButton);
setTimeBarMinUpdateInterval(
a.getInt(
- R.styleable.StyledPlayerControlView_time_bar_min_update_interval,
+ R.styleable.PlayerControlView_time_bar_min_update_interval,
timeBarMinUpdateIntervalMs));
animationEnabled =
- a.getBoolean(R.styleable.StyledPlayerControlView_animation_enabled, animationEnabled);
+ a.getBoolean(R.styleable.PlayerControlView_animation_enabled, animationEnabled);
} finally {
a.recycle();
}
@@ -1572,7 +1564,7 @@ public class PlayerControlView extends FrameLayout {
@SuppressWarnings("ResourceType")
private static @RepeatModeUtil.RepeatToggleModes int getRepeatToggleModes(
TypedArray a, @RepeatModeUtil.RepeatToggleModes int defaultValue) {
- return a.getInt(R.styleable.StyledPlayerControlView_repeat_toggle_modes, defaultValue);
+ return a.getInt(R.styleable.PlayerControlView_repeat_toggle_modes, defaultValue);
}
private final class ComponentListener
@@ -89,12 +89,12 @@ import java.util.concurrent.CopyOnWriteArrayList;
Attributes
*
- * The following attributes can be set on a StyledPlayerControlView when used in a layout XML file:
+ * The following attributes can be set on a PlayerControlView when used in a layout XML file:
*
*
@@ -160,13 +160,13 @@ import java.util.concurrent.CopyOnWriteArrayList;
*
* All attributes that can be set on {@link DefaultTimeBar} can also be set on a
- * StyledPlayerControlView, and will be propagated to the inflated {@link DefaultTimeBar}
- * unless the layout is overridden to specify a custom {@code exo_progress} (see below).
+ * PlayerControlView, and will be propagated to the inflated {@link DefaultTimeBar} unless the
+ * layout is overridden to specify a custom {@code exo_progress} (see below).
*
*
@@ -160,13 +160,13 @@ import java.util.concurrent.CopyOnWriteArrayList;
* Overriding drawables
*
- * The drawables used by StyledPlayerControlView (with its default layout file) can be overridden by
+ * The drawables used by PlayerControlView (with its default layout file) can be overridden by
* drawables with the same names defined in your application. The drawables that can be overridden
* are: